function residual = OptimizeBPSignal(signalLandmarks)

load calibrationHR calibrationHR;
load calibrationAge calibrationAge;
load baselineFlow baselineFlow;
load signal signal;

HR = calibrationHR;
age = calibrationAge;
Vbas = baselineFlow;
calibrationCBF = signal;

% Interpolate BP signal from landmarks to continuous signal
landmarks = [ 1 8 10 12 16 18 20 22 24 26 28 32 34  38 42 46 60 95 100];
BP = interp1(0.01*landmarks,[signalLandmarks; signalLandmarks(1)],linspace(0,1,100),'pchip');

% Parameters for elderly subjects
aE = 2.5;
bE = 0.28;
cE = 2.71;
ME = 1.00;

% Parameters for middle-aged subjects
aM = 0.438;
bM = 0.01;
cM = 0.264;
MM = 1.2;

if (age < 35)
    a = aM; b = bM; c = cM; M = MM;
elseif (age > 75)
    a = aE; b = bE; c = cE; M = ME;
else
    lambda = (75-age)/(75-35);
    a = aM * lambda + (1 - lambda) * aE;
    b = bM * lambda + (1 - lambda) * bE;
    c = cM * lambda + (1 - lambda) * cE;
    M = MM * lambda + (1 - lambda) * ME;
end

f_s = mean(BP); % Initial values fitting the MAP

f_aut = 2.03e-6 * f_s.^3 - 6.02e-4 * f_s.^2 + 5.94e-2 * f_s - 1.95;
d = b * c * f_aut / (M * c * f_s - (a + c) * f_aut);

init_v(1) = f_s * (b * c + a * d) / (b * c + (a + c) * d);
init_v(2) =(b * c * f_s) / (b * c + (a + c) * d);
[t,v] = ode23s(@OlufsenModel,0:0.01:40*60/HR,init_v,[],HR,BP,age);

% Driving force is equal to the arterial pressure
for n=1:length(t)   
    f_s(n) = ArterialPressure(t(n),HR,BP);
end


Vdyn = M * (f_s' - v(:,1));
V  = Vbas + Vdyn; 

% Truncate to last heartbeat
hb_length = floor(60/HR/0.01);
CBF = V(38*hb_length+1:39*hb_length+1);

%[GARBO,IMAX] = max(diff(CBF(1:30)));
%CBF = CBF([IMAX:end 1:IMAX-1]);
%CBF = CBF([hb_length-10:hb_length 1:hb_length-11]);

if (hb_length < 100)
    CBF = [CBF; CBF(end)*ones(60,1)];
    CBF = CBF(1:100);
end

CBF = CBF(landmarks);

residual = norm(CBF(1:end-1) - calibrationCBF', 2)^2;
%figure(1)
%plot(landmarks(1:end-1),calibrationCBF,'ko',landmarks,CBF,'b--','LineWidth',2)
%pause(0.01)