% Mader et al. 2015 model used for estimating intra-subject variability
% envelopes of ICA flow with variables SBP/DBP/HR given an example of ICA
% flow at one specific set of SBP/DBP/HR values

% Convert calibration signal to ICA flow velocity
calibrationTime   = calibrationSignal(:,1)/1000;
calibrationHR   = 60/(calibrationTime(end)-calibrationTime(1));
calibrationSignal = calibrationSignal(:,2);
calibrationSignal = calibrationSignal / (pi * (calibrationDiam/2)^2);

baselineFlow      = mean(calibrationSignal)-2;

% Convert calibration signal to MCA flow velocity (model output)
if (isFemale == 1)
    calibrationSignal = (1.67 + calibrationAge * 0.005) * calibrationSignal;    
else
    calibrationSignal = 2 * calibrationSignal; 
end

% Convert baseline to MCA flow velocity
if (isFemale == 1)
    baselineFlow = (1.67 + calibrationAge * 0.005) * baselineFlow;    
else
    baselineFlow = 2 * baselineFlow; 
end

% Rescale and shift calibration signal maximum to t=28
calibrationSignal = interp1(calibrationTime, calibrationSignal, linspace(0,1,100),'pchip');
[GARBO,IMAX]      = max(calibrationSignal);
calibrationSignal = calibrationSignal([IMAX:end 1:IMAX-1]);
calibrationSignal = calibrationSignal([72:end 1:71]);

% Load initial guess for pressure signal (at 72 bpm)
%LoadInitialGuessPressure;
initialGuessPressure = calibrationSignal';
landmarks = [ 1 8 10 12 16 18 20 22 24 26 28 32 34  38 42 46 60 95 ];
initialGuessPressure = initialGuessPressure(landmarks);

% Rescale pressure signal
initialGuessPressure = initialGuessPressure - min(initialGuessPressure);
initialGuessPressure = initialGuessPressure / max(initialGuessPressure);
initialGuessPressure = initialGuessPressure * (calibrationSBP - calibrationDBP) + calibrationDBP;

% Make signal periodic to avoid discontinuities
initialGuessPressure(16:18) = initialGuessPressure(16:18)*1.1;
initialGuessPressure(end) = initialGuessPressure(1);


opts = optimset('Display', 'iter');
save calibrationHR calibrationHR;
save calibrationAge calibrationAge;
save baselineFlow baselineFlow;
signal = calibrationSignal(landmarks);
save signal signal;
%opt_landmarks = ga(@OptimizeBPSignal, 18, [],[],[],[],60*ones(1,18),150*ones(1,18),[],[], opts)
opt_landmarks = fminunc(@OptimizeBPSignal, initialGuessPressure, opts);