%% % Please cite the reference below when using this model.
%
% Reference: Lassila T, Sarrami-Foroushani A, Hejazi S, Frangi AF. 
% Population-Specific Modelling of Between/Within-Subject Flow Variability 
% in the Carotid Arteries of the Elderly, preprint, 2018.
%
% Copyright license: CC-BY-4.0
%% DEMO 1 - Single case run
% Intra-subject variability model - single case run
% Demo: modelling the effect of exercise on internal carotid flow wave
% forms
%
% Effect of exercise on pressure waves at the middle cerebral artery -
% Based on measurements performed by Ogoh et al. 2005 
SBP_sf = 1.3; % systolicBP_exer / systolicBP_rest according to Ogoh et al.
HR_sf  = 2.2; % HR_exer / HR_rest according to Ogoh et al.
%
%%
% Exemplar case 
% Inputs:
gender = 'Female';            % gender
age    = 45;                  % age - [yrs]
inletArea = 0.0000196;        % characteristic internal carotid cross-sectional area (inlet) [m^2]
tagCASE         = 'case01';   % case name
% Outputs:
% velocity magnitude waveforms [cm s-1] at rest and exercise - will be written as txt
% files in ./demo_1/<case name>.
% note: velocity magnitudes will be scaled to ensure a physiological wall shear
% stress of 1.5 Pa on the lumen at the inlet. 
%
%%
tagSCRIPTSROOT  = pwd;
tagTEMPROOT     = [pwd, '/demo_1/'];

main_inflowGen(gender,age,tagSCRIPTSROOT,inletArea,tagTEMPROOT,tagCASE,SBP_sf,HR_sf)
