%% % Please cite the reference below when using this model.
%
% Reference: Lassila T, Sarrami-Foroushani A, Hejazi S, Frangi AF. 
% Population-Specific Modelling of Between/Within-Subject Flow Variability 
% in the Carotid Arteries of the Elderly, preprint, 2018.
%
% Copyright license: CC-BY-4.0
%% DEMO 2 - visualisation of flow variability
% input paths
rest_waves_path = [pwd, '/demo_2/inflowWaves/rest'];
exer_waves_path = [pwd, '/demo_2/inflowWaves/exercise'];
% ouput figure
outputFig_fileName = [pwd, '/demo_2/velocityWaves.png'];
%
%%
rest_waves_names = dir(rest_waves_path);
exer_waves_names = dir(exer_waves_path);
%
for i = 3:size(rest_waves_names,1)
    wave_name = rest_waves_names(i).name;
    wave = importdata([rest_waves_path,'\',wave_name]);
    wave = reshape(wave,2,100)';
    time_rest(:,i-2) = wave(:,1);
    wave_rest(:,i-2) = wave(:,2);
end

%
for i = 3:size(exer_waves_names,1)
    wave_name = exer_waves_names(i).name;
    wave = importdata([exer_waves_path,'\',wave_name]);
    wave = reshape(wave,2,100)';
    time_exer(:,i-2) = wave(:,1);
    wave_exer(:,i-2) = wave(:,2);
end

%figure;plot(time_rest,wave_rest)
%figure;plot(time_exer,wave_exer)
%%
% plots show velocity waveforms +/- SD
% blue: rest condition
% red:  exercise
figure;shadedErrorBar(time_rest(:,1),wave_rest',{@mean,@std},'lineprops', '-b','transparent',true,'patchSaturation',0.075);hold on;
shadedErrorBar(time_exer(:,1),wave_exer',{@mean,@std},'lineprops', '-r','transparent',true,'patchSaturation',0.075);
xlabel('time, [s]')
ylabel('velocity magnitude, [cm/s]')
P=get(gca,'Children');
legend([P(4),P(8)],{'Exercise','Rest'})
saveas(gcf,outputFig_fileName)




